pub struct RankingModel<T: Clone + Debug + Eq + Hash + Display + Send + Sync + 'static> {
pub data: ComparisonMatrix<T>,
pub scores: Option<HashMap<T, f64>>,
/* private fields */
}Expand description
Main ASAP ranking model for inferring scores from pairwise comparisons
Fields
data: ComparisonMatrix<T>scores: Option<HashMap<T, f64>>Implementations
Sourceimpl<T: Clone + Debug + Eq + Hash + Display + Send + Sync + 'static> RankingModel<T>
impl<T: Clone + Debug + Eq + Hash + Display + Send + Sync + 'static> RankingModel<T>
Sourcepub fn new_with_options(
items: &[T],
approximate: bool,
selective_eig: bool,
) -> Self
pub fn new_with_options( items: &[T], approximate: bool, selective_eig: bool, ) -> Self
Create a new RankingModel with custom options
Sourcepub fn add_comparison(
&mut self,
comparison: Comparison<T>,
) -> Result<(), AsapError<T>>
pub fn add_comparison( &mut self, comparison: Comparison<T>, ) -> Result<(), AsapError<T>>
Add a pairwise comparison result
pub fn add_item(&mut self, item: T) -> Result<(), AsapError<T>>
pub fn remove_item(&mut self, item: &T) -> Result<(), AsapError<T>>
Sourcepub fn get_ordering(&mut self) -> Result<Vec<T>, AsapError<T>>
pub fn get_ordering(&mut self) -> Result<Vec<T>, AsapError<T>>
Get the items ordered by their inferred scores (highest to lowest)
Sourcepub fn get_scores(&mut self) -> Result<HashMap<T, f64>, AsapError<T>>
pub fn get_scores(&mut self) -> Result<HashMap<T, f64>, AsapError<T>>
Get the inferred scores for all items
Sourcepub fn suggest_comparisons(
&self,
max: usize,
) -> Result<Vec<(T, T)>, AsapError<T>>
pub fn suggest_comparisons( &self, max: usize, ) -> Result<Vec<(T, T)>, AsapError<T>>
Suggest the most informative comparisons to perform next
Sourcepub fn ranking_confidence(&self) -> Result<f64, AsapError<T>>
pub fn ranking_confidence(&self) -> Result<f64, AsapError<T>>
Confidence metric calibrated for Bradley-Terry MLE.
Measures two things:
- Coverage (50% weight): fraction of items with >= MIN_COMPARISONS_PER_ITEM comparisons. BT needs ~5-10 per item, not N² total.
- Discrimination (50% weight): whether scores are spread out enough to distinguish items. Uses coefficient of variation of the BT strengths.